@@ -2,6 +2,7 @@ import numpy as np
 import sympy as sym
 import math
 import pyquaternion as pqu
+import __future__
 
 
 class Octonion:
@@ -53,17 +54,6 @@ class Octonion:
 
     @property
     def conjugate(self):
-        """r_2 = [
-            self.x_0,
-            -(self.x_1),
-            -(self.x_2),
-            -(self.x_3),
-            -(self.x_4),
-            -(self.x_5),
-            -(self.x_6),
-            -(self.x_7),
-        ]
-        a_2 = np.array(r_2, float)"""
         conj = Octonion(
             self.x_0,
             -(self.x_1),
@@ -259,7 +249,7 @@ class Octonion:
             return addition
         raise NotImplementedError
 
-    def __rtruediv__(x, y):
+    def __rtruediv__(y, x):
         if isinstance(y, Octonion):
             conj = Octonion(
                 y.x_0,
@@ -403,7 +393,7 @@ class Octonion:
         raise NotImplementedError
 
     def __sub__(x, y):
-        if isinstance(y, Octonion):
+        if isinstance(y, Octonion) and isinstance(x, Octonion):
             total = [
                 x.x_0 - y.x_0,
                 x.x_1 - y.x_1,
@@ -444,7 +434,7 @@ class Octonion:
         # print(x)
         # print(y)
         if isinstance(y, Octonion):
-            total = [x - y.x_0, y.x_1, y.x_2, y.x_3, y.x_4, y.x_5, y.x_6, y.x_7]
+            total = [x - y.x_0, -y.x_1, -y.x_2, -y.x_3, -y.x_4, -y.x_5, -y.x_6, -y.x_7]
             addition = Octonion(
                 total[0],
                 total[1],
@@ -470,13 +460,42 @@ class Octonion:
             self.x_7,
         )
 
+    def __pow__(x, pow):
+        if isinstance(x, Octonion):
+            y = Octonion(x.x_0, x.x_1, x.x_2, x.x_3, x.x_4, x.x_5, x.x_6, x.x_7)
+            while pow > 1:
+                # print(y)
+                a = pqu.Quaternion(x.x_0, x.x_1, x.x_2, x.x_3)
+                b = pqu.Quaternion(x.x_4, x.x_5, x.x_6, x.x_7)
+                c = pqu.Quaternion(y.x_0, y.x_1, y.x_2, y.x_3)
+                d = pqu.Quaternion(y.x_4, y.x_5, y.x_6, y.x_7)
+                a_1 = a * c - (d.conjugate) * b
+                b_1 = (d * a) + (b * (c.conjugate))
+                y = Octonion(
+                    a_1[0], a_1[1], a_1[2], a_1[3], b_1[0], b_1[1], b_1[2], b_1[3]
+                )
+                pow -= 1
+            return y
+        raise NotImplementedError
+
 
 b = Octonion(1, 0, 0, 0, 0, 0, 1, 1)
-c = Octonion(1, 0, 0, 0, 0, 0, 0, 1)
-print(b / c)
-print(2 / b)
-print(b / 2)
+# c = Octonion(1, 0, 0, 0, 0, 0, 0, 1)
+print(b ** 300)
+# print(b ** 3)
+# print('b*b*b')
+# print(b*b*b)
+# print('c**4')
+# print(c ** 4)
+# print('c*c*c*c')
+# print(c*c*c*c)
+
+
+# print(b / c)
+# print(2 / b)
 # print(b / 2)
+# print(b * 5)
+# print(5 * b)
 # print(2 / b)
 
 # print(b * c)
@@ -503,4 +522,3 @@ print(b / 2)
 # octonion.oct_quad(0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8)
 
 # octonion.oct_quad(1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16)
-
